Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(428)

Unified Diff: ios/web_view/public/cwv.h

Issue 2703413004: Rename CRIWV class to CWV. (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ios/web_view/public/criwv.h ('k') | ios/web_view/public/cwv_delegate.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ios/web_view/public/cwv.h
diff --git a/ios/web_view/public/criwv.h b/ios/web_view/public/cwv.h
similarity index 59%
rename from ios/web_view/public/criwv.h
rename to ios/web_view/public/cwv.h
index b700569b8ad87e4e76bc7f4ae2f50971c8e9b992..503d5f786a2552d017ac1a2e67a58ee11f2c29af 100644
--- a/ios/web_view/public/criwv.h
+++ b/ios/web_view/public/cwv.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef IOS_WEB_VIEW_PUBLIC_CRIWV_H_
-#define IOS_WEB_VIEW_PUBLIC_CRIWV_H_
+#ifndef IOS_WEB_VIEW_PUBLIC_CWV_H_
+#define IOS_WEB_VIEW_PUBLIC_CWV_H_
#import <CoreGraphics/CoreGraphics.h>
#import <Foundation/Foundation.h>
@@ -11,15 +11,14 @@
@protocol CWVDelegate;
@class CWVWebView;
-// Main interface for the CRIWV library.
-__attribute__((visibility("default")))
-@interface CRIWV : NSObject
+// Main interface for the CWV library.
+__attribute__((visibility("default"))) @interface CWV : NSObject
-// Initializes the CRIWV library. This function should be called from
+// Initializes the CWV library. This function should be called from
// |application:didFinishLaunchingWithOptions:|.
+ (void)configureWithDelegate:(id<CWVDelegate>)delegate;
-// Shuts down the CRIWV library. This function should be called from
+// Shuts down the CWV library. This function should be called from
// |applicationwillTerminate:|.
+ (void)shutDown;
@@ -28,4 +27,4 @@ __attribute__((visibility("default")))
@end
-#endif // IOS_WEB_VIEW_PUBLIC_CRIWV_H_
+#endif // IOS_WEB_VIEW_PUBLIC_CWV_H_
« no previous file with comments | « ios/web_view/public/criwv.h ('k') | ios/web_view/public/cwv_delegate.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698